#!/bin/sh
# 
# chkconfig: 345 95 05
# description: ndo DB Broker
#
# File : ndo2db
#
# Description: Starts and stops the ndo monitor broker
#              to database bridge
#
# Author: Sascha Runschke <Sascha.Runschke@gfkl.com>
#         GFKL Financial Services AG, Germany
#
# Licensed under the GNU Public License v2
#
# ATTENTION:
# The fact that subSys handling prohibits the use of multiple ndo2db daemons
# is no bug, but working as intended.
#
# Changelog:
#
# 05.01.2009 - Further adjusting the script to RHEL standards using RETVAL and subsys handling
# 05.11.2008 - Rewrite to make real use of /etc/init.d/functions along with daemon() and killproc()
# 05.06.2008 - Initial writing
# 
# ToDo:
# - check if the initscript works on other distributions or unix derivates
# - implement pidFile support into ndo2db
#

# Source function library
# Solaris doesn't have an rc.d directory, so do a test first
if [ -f /etc/rc.d/init.d/functions ]; then
	. /etc/rc.d/init.d/functions
elif [ -f /etc/init.d/functions ]; then
	. /etc/init.d/functions
# Somethings broken with that check, yet no time currently to fix it
#elif
#	echo "ERROR - this script uses daemon() and killproc() functions and therefor needs the sysV /etc/init.d/functions script!"
#	exit 1
fi

prefix=/usr/local/nagios
ndoBin=${prefix}/bin/ndo2db
ndoCfgFile=${prefix}/etc/ndo2db.cfg
ndoVarDir=${prefix}/var
ndoSubsys=/var/lock/subsys/ndo2db
# The ndoPidFile is currently not really used, since it's not implemented in nagios - work pending
ndoPidFile=/var/run/nagios/ndo.pid
ndoUser=nagios
ndoGroup=nagios
          

# Check that ndo exists.
if [ ! -x $ndoBin ]; then
	echo -n $"Executable file $ndoBin not found.  Exiting. "
	echo
	echo_failure
	exit 1
fi

# Check that ndo.cfg exists.
if [ ! -f $ndoCfgFile ]; then
    echo -n $"Configuration file $ndoCfgFile not found.  Exiting. "
    echo
    echo_failure
    exit 1
fi

start() {
	# Check for $ndoVarDir/ndo.sock and bail out on existance as ndo2db must have crashed before
	if [ -e $ndoVarDir/ndo.sock ] ; then
		echo -n $"$ndoVarDir/ndo.sock exists - daemon crashed before? "
		echo_failure
		echo
		exit 1
	fi
	echo -n $"Starting Nagios ndo2db: "
	daemon --user $ndoUser --pidfile $ndoPidFile $ndoBin -c $ndoCfgFile
	RETVAL=$?
	echo
	[ $RETVAL -eq 0 ] && touch $ndoSubsys
}

stop() {
	echo -n $"Stopping ndo: "
	killproc $ndoBin
	RETVAL=$?
	echo
	[ $RETVAL -eq 0 ] && rm -f $ndoSubsys $ndoPidFile $ndoStatusFile
}

# See how we were called.
case "$1" in

	start)
		start
		;;

	stop)
		stop
		;;

	status)
		status $ndoBin
		;;
	restart)
		stop
		start
		;;

	*)
		echo "Usage: ndo2db {start|stop|restart|status}"
		exit 1
		;;

esac
  
# End of this script
